@@ -13,37 +13,22 @@ class Device(object):
     # Property variables
     __id = None
     __zone = None
-    __location = None
     __device_type = None
-    __type = None
     __subtype = None
     __preenroll = None
-    __soak = None
-    __bypass = None
-    __alarms = None
-    __alerts = None
-    __troubles = None
-    __bypass_availability = None
+    __warnings = None
     __partitions = None
 
-    def __init__(self, id, zone, location, device_type, type, subtype,
-                 preenroll, soak, bypass, alarms, alerts, troubles,
-                 bypass_availability, partitions):
+    def __init__(self, id, zone, device_type, subtype,
+                 preenroll, warnings, partitions):
         """ Set the private variable values on instantiation. """
 
         self.__id = id
         self.__zone = zone
-        self.__location = location
         self.__device_type = device_type
-        self.__type = type
         self.__subtype = subtype
         self.__preenroll = preenroll
-        self.__soak = soak
-        self.__bypass = bypass
-        self.__alarms = alarms
-        self.__alerts = alerts
-        self.__troubles = troubles
-        self.__bypass_availability = bypass_availability
+        self.__warnings = warnings
         self.__partitions = partitions
 
     # Device properties
@@ -57,21 +42,11 @@ class Device(object):
         """ Device zone. """
         return self.__zone
 
-    @property
-    def location(self):
-        """ Device location. """
-        return self.__location
-
     @property
     def device_type(self):
         """ Device: device type. """
         return self.__device_type
 
-    @property
-    def type(self):
-        """ Device type. """
-        return self.__type
-
     @property
     def subtype(self):
         """ Device subtype. """
@@ -83,34 +58,9 @@ class Device(object):
         return self.__preenroll
 
     @property
-    def soak(self):
-        """ Device soak. """
-        return self.__soak
-
-    @property
-    def bypass(self):
-        """ Device bypassed. """
-        return self.__bypass
-
-    @property
-    def alarms(self):
+    def warnings(self):
         """ Device alarm count. """
-        return self.__alarms
-
-    @property
-    def alerts(self):
-        """ Device alert count. """
-        return self.__alerts
-
-    @property
-    def troubles(self):
-        """ Device trouble count. """
-        return self.__troubles
-
-    @property
-    def bypass_availability(self):
-        """ Device bypass_availability. """
-        return self.__bypass_availability
+        return self.__warnings
 
     @property
     def partitions(self):
@@ -125,8 +75,8 @@ class ContactDevice(Device):
     def state(self):
         """ Returns the current state of the contact. """
 
-        if self.troubles:
-            if 'OPENED' in self.troubles:
+        if self.warnings:
+            if 'OPENED' in self.warnings:
                 return 'opened'
         else:
             return 'closed'
@@ -257,18 +207,10 @@ class System(object):
         """ Send Arm Home command to the alarm system. """
         self.__api.arm_home(self.__api.partition)
 
-    def arm_home_instant(self):
-        """ Send Arm Home Instant command to the alarm system. """
-        self.__api.arm_home_instant(self.__api.partition)
-
     def arm_away(self):
         """ Send Arm Away command to the alarm system. """
         self.__api.arm_away(self.__api.partition)
 
-    def arm_away_instant(self):
-        """ Send Arm Away Instant command to the alarm system. """
-        self.__api.arm_away_instant(self.__api.partition)
-
     def connect(self):
         """ Connect to the alarm system and get the static system info. """
 
@@ -290,7 +232,6 @@ class System(object):
 
         # Get general panel information
         gpi = self.__api.get_general_panel_info()
-        self.__system_name = gpi['name']
         self.__system_serial = gpi['serial']
         self.__system_model = gpi['model']
 
@@ -370,18 +311,12 @@ class System(object):
             print('--------------')
             print('ID:             {0}'.format(device.id))
             print('Zone:           {0}'.format(device.zone))
-            print('Location:       {0}'.format(device.location))
             print('Device Type:    {0}'.format(device.device_type))
-            print('Type:           {0}'.format(device.type))
             print('Subtype:        {0}'.format(device.subtype))
-            print('Alarms:         {0}'.format(device.alarms))
-            print('Alerts:         {0}'.format(device.alerts))
-            print('Troubles:       {0}'.format(device.troubles))
+            print('Warnings:         {0}'.format(device.warnings))
+
             if detailed:
                 print('Pre-enroll:     {0}'.format(device.pre_enroll))
-                print('Soak:           {0}'.format(device.soak))
-                print('Bypass:         {0}'.format(device.bypass))
-                print('Bypass Avail.:  {0}'.format(device.bypass_availability))
                 print('Partitions:     {0}'.format(device.partitions))
             if isinstance(device, ContactDevice):
                 print('State:          {0}'.format(device.state))
@@ -450,17 +385,10 @@ class System(object):
                 contact_device = ContactDevice(
                     id=device['id'],
                     zone=device['zone_type'],
-                    location=device['location'],
                     device_type=device['device_type'],
-                    type=device['type'],
                     subtype=device['subtype'],
                     preenroll=device['preenroll'],
-                    soak=device['soak'],
-                    bypass=device['bypass'],
-                    alarms=device['alarms'],
-                    alerts=device['alerts'],
-                    troubles=device['troubles'],
-                    bypass_availability=device['bypass_availability'],
+                    warnings=device['warnings'],
                     partitions=device['partitions']
                 )
                 self.__system_devices.append(contact_device)
@@ -468,17 +396,10 @@ class System(object):
                 camera_device = CameraDevice(
                     id=device['id'],
                     zone=device['zone_type'],
-                    location=device['location'],
                     device_type=device['device_type'],
-                    type=device['type'],
                     subtype=device['subtype'],
                     preenroll=device['preenroll'],
-                    soak=device['soak'],
-                    bypass=device['bypass'],
-                    alarms=device['alarms'],
-                    alerts=device['alerts'],
-                    troubles=device['troubles'],
-                    bypass_availability=device['bypass_availability'],
+                    warnings=device['warnings'],
                     partitions=device['partitions']
                 )
                 self.__system_devices.append(camera_device)
@@ -486,17 +407,10 @@ class System(object):
                 motion_device = MotionDevice(
                     id=device['id'],
                     zone=device['zone_type'],
-                    location=device['location'],
                     device_type=device['device_type'],
-                    type=device['type'],
                     subtype=device['subtype'],
                     preenroll=device['preenroll'],
-                    soak=device['soak'],
-                    bypass=device['bypass'],
-                    alarms=device['alarms'],
-                    alerts=device['alerts'],
-                    troubles=device['troubles'],
-                    bypass_availability=device['bypass_availability'],
+                    warnings=device['warnings'],
                     partitions=device['partitions']
                 )
                 self.__system_devices.append(motion_device)
@@ -504,17 +418,10 @@ class System(object):
                 smoke_device = SmokeDevice(
                     id=device['id'],
                     zone=device['zone_type'],
-                    location=device['location'],
                     device_type=device['device_type'],
-                    type=device['type'],
                     subtype=device['subtype'],
                     preenroll=device['preenroll'],
-                    soak=device['soak'],
-                    bypass=device['bypass'],
-                    alarms=device['alarms'],
-                    alerts=device['alerts'],
-                    troubles=device['troubles'],
-                    bypass_availability=device['bypass_availability'],
+                    warnings=device['warnings'],
                     partitions=device['partitions']
                 )
                 self.__system_devices.append(smoke_device)
@@ -522,17 +429,10 @@ class System(object):
                 generic_device = GenericDevice(
                     id=device['id'],
                     zone=device['zone_type'],
-                    location=device['location'],
                     device_type=device['device_type'],
-                    type=device['type'],
                     subtype=device['subtype'],
                     preenroll=device['preenroll'],
-                    soak=device['soak'],
-                    bypass=device['bypass'],
-                    alarms=device['alarms'],
-                    alerts=device['alerts'],
-                    troubles=device['troubles'],
-                    bypass_availability=device['bypass_availability'],
+                    warnings=device['warnings'],
                     partitions=device['partitions']
                 )
                 self.__system_devices.append(generic_device)
@@ -667,9 +567,9 @@ class API(object):
         if with_user_token:
             headers['User-Token'] = self.__user_token
 
-        logging.error('POST REQUEST -> ' + url)
-        logging.error(headers)
-        logging.error(data_json)
+        logging.debug('POST REQUEST -> ' + url)
+        logging.debug(headers)
+        logging.debug(data_json)
 
         # Perform the request and raise an exception
         # if the response is not OK (HTML 200)
@@ -679,11 +579,11 @@ class API(object):
         # Check HTTP response code
         if response.status_code == requests.codes.ok:
             resp = json.loads(response.content.decode('utf-8'))
-            logging.error(resp)
+            logging.debug(resp)
 
             return resp
         else:
-            logging.error(response)
+            logging.debug(response)
             return None
 
     ######################
@@ -861,7 +761,7 @@ class API(object):
     def arm_home(self, partition):
         """ Arm in Home mode and with Exit Delay. """
         arm_info = {
-            'partition': partition,
+            'partition': -1,
             'state': "HOME"
         }
         arm_json = json.dumps(arm_info, separators=(',', ':'))
@@ -873,7 +773,7 @@ class API(object):
     def arm_away(self, partition):
         """ Arm in Away mode and with Exit Delay. """
         arm_info = {
-            'partition': partition,
+            'partition': -1,
             'state': "AWAY"
         }
         arm_json = json.dumps(arm_info, separators=(',', ':'))
@@ -885,7 +785,7 @@ class API(object):
     def disarm(self, partition):
         """ Disarm the alarm system. """
         disarm_info = {
-            'partition': partition,
+            'partition': -1,
             'state': "DISARM"
         }
         disarm_json = json.dumps(disarm_info, separators=(',', ':'))
